==> phoenix_widgets-1.16.5.tar.gz: lib/phoenix_expandable_list.dart <==
import 'package:flutter/material.dart';

class PhoenixExpandableList extends StatelessWidget {
  const PhoenixExpandableList({
    Key? key,
    required this.expendableData,
    this.margin,
    this.padding,
    this.titlePadding,
    this.expandColor,
    this.shrinkColor,
    this.radius,
    this.expandImage,
    this.shrinkImage,
    required this.showData,
    required this.callback,
  }) : super(key: key);
  final ExpendableData expendableData;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? padding;
  final EdgeInsetsGeometry? titlePadding;
  final Color? expandColor;
  final Color? shrinkColor;
  final double? radius;
  final Widget? expandImage;
  final Widget? shrinkImage;
  final bool showData;
  final VoidCallback callback;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: radius != null ? BorderRadius.circular(radius!) : null,
        color:
            showData ? expandColor ?? Colors.white : shrinkColor ?? Colors.grey,
      ),
      margin: margin ?? const EdgeInsets.all(16),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Material(
            color: Colors.transparent,
            child: InkWell(
              onTap: () {
                callback();
              },
              child: Ink(
                child: Padding(
                  padding: titlePadding ?? const EdgeInsets.all(16),
                  child: Row(
                    children: [
                      Expanded(child: expendableData.title),
                      Container(
                        margin: const EdgeInsets.only(left: 16),
                      ),
                      showData
                          ? shrinkImage ?? const Icon(Icons.add)
                          : expandImage ?? const Icon(Icons.minimize),
                    ],
                  ),
                ),
              ),
            ),
          ),
          showData
              ? Container(
                  margin: const EdgeInsets.only(top: 8, bottom: 16),
                  child: expendableData.content,
                )
              : const SizedBox(),
        ],
      ),
    );
  }
}

class ExpendableData {
  ExpendableData({required this.title, required this.content});

  Widget title;
  Widget content;
  bool show = false;
}

==> phoenix_widgets-1.19.0.tar.gz: lib/phoenix_expandable_list.dart <==
import 'package:flutter/material.dart';

class PhoenixExpandableList extends StatelessWidget {
  const PhoenixExpandableList({
    Key? key,
    required this.expendableData,
    this.margin,
    this.contentMargin,
    this.padding,
    this.titlePadding,
    this.expandColor,
    this.shrinkColor,
    this.radius,
    this.expandImage,
    this.shrinkImage,
    required this.showData,
    required this.callback,
  }) : super(key: key);
  final ExpendableData expendableData;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? contentMargin;
  final EdgeInsetsGeometry? padding;
  final EdgeInsetsGeometry? titlePadding;
  final Color? expandColor;
  final Color? shrinkColor;
  final double? radius;
  final Widget? expandImage;
  final Widget? shrinkImage;
  final bool showData;
  final VoidCallback callback;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: radius != null ? BorderRadius.circular(radius!) : null,
        color:
            showData ? expandColor ?? Colors.white : shrinkColor ?? Colors.grey,
      ),
      margin: margin ?? const EdgeInsets.all(16),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Material(
            color: Colors.transparent,
            child: InkWell(
              onTap: () {
                callback();
              },
              child: Ink(
                child: Padding(
                  padding: titlePadding ?? const EdgeInsets.all(16),
                  child: Row(
                    children: [
                      Expanded(child: expendableData.title),
                      Container(
                        margin: const EdgeInsets.only(left: 16),
                      ),
                      showData
                          ? shrinkImage ?? const Icon(Icons.add)
                          : expandImage ?? const Icon(Icons.minimize),
                    ],
                  ),
                ),
              ),
            ),
          ),
          showData
              ? Container(
                  margin: contentMargin ??
                      const EdgeInsets.only(top: 8, bottom: 16),
                  child: expendableData.content,
                )
              : const SizedBox(),
        ],
      ),
    );
  }
}

class ExpendableData {
  ExpendableData({required this.title, required this.content});

  Widget title;
  Widget content;
  bool show = false;
}
